"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtOpenGL import *


class QOpenGLShaderProgram(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qopenglshaderprogram.html

    **Detailed Description**

    **Introduction**

    This class supports shader programs written in the OpenGL Shading Language
    (GLSL) and in the OpenGL/ES Shading Language (GLSL/ES).

    **QOpenGLShader**  and QOpenGLShaderProgram shelter the programmer from the
    details of compiling and linking vertex and fragment shaders.

    The following example creates a vertex shader program using the supplied
    source `code`. Once compiled and linked, the shader program is activated in
    the current **QOpenGLContext**  by calling **QOpenGLShaderProgram::bind**
    ():

    **QOpenGLShader**  shader(**QOpenGLShader** ::Vertex);
    shader.compileSourceCode(code);

        **QOpenGLShaderProgram**
    program(context);
        program.addShader(&shader);
        program.link();
    program.bind();

    **Writing Portable Shaders**

    Shader programs can be difficult to reuse across OpenGL implementations
    because of varying levels of support for standard vertex attributes and
    uniform variables. In particular, GLSL/ES lacks all of the standard
    variables that are present on desktop OpenGL systems: `gl_Vertex`,
    `gl_Normal`, `gl_Color`, and so on. Desktop OpenGL lacks the variable
    qualifiers `highp`, `mediump`, and `lowp`.

    The QOpenGLShaderProgram class makes the process of writing portable shaders
    easier by prefixing all shader programs with the following lines on desktop
    OpenGL:

    #define highp
        #define mediump
        #define lowp

    This makes it possible to run most GLSL/ES shader programs on desktop
    systems. The programmer should restrict themselves to just features that are
    present in GLSL/ES, and avoid standard variable names that only work on the
    desktop.

    **Simple Shader Example**

    program.addShaderFromSourceCode(**QOpenGLShader** ::Vertex,
    "attribute highp vec4 vertex;\\n"
            "uniform highp mat4 matrix;\\n"
    "void main(void)\\n"
            "{\\n"
            "   gl_Position = matrix *
    vertex;\\n"
            "}");
    program.addShaderFromSourceCode(**QOpenGLShader** ::Fragment,
    "uniform mediump vec4 color;\\n"
            "void main(void)\\n"
            "{\\n"
    "   gl_FragColor = color;\\n"
            "}");
        program.link();
    program.bind();

        int vertexLocation =
    program.attributeLocation("vertex");
        int matrixLocation =
    program.uniformLocation("matrix");
        int colorLocation =
    program.uniformLocation("color");

    With the above shader program active, we can draw a green triangle as
    follows:

    static GLfloat const triangleVertices[] = {
            60.0f,  10.0f,  0.0f,
    110.0f, 110.0f, 0.0f,
            10.0f,  110.0f, 0.0f
        };
    **QColor**  color(0, 255, 0, 255);

        QMatrix4x4 pmvMatrix;
    pmvMatrix.ortho(rect());
    program.enableAttributeArray(vertexLocation);
    program.setAttributeArray(vertexLocation, triangleVertices, 3);
    program.setUniformValue(matrixLocation, pmvMatrix);
    program.setUniformValue(colorLocation, color);
    glDrawArrays(GL_TRIANGLES, 0, 3);
    program.disableAttributeArray(vertexLocation);

    **Binary Shaders and Programs**

    Binary shaders may be specified using `glShaderBinary()` on the return value
    from **QOpenGLShader::shaderId** (). The **QOpenGLShader**  instance
    containing the binary can then be added to the shader program with
    **addShader** () and linked in the usual fashion with **link** ().

    Binary programs may be specified using `glProgramBinaryOES()` on the return
    value from **programId** (). Then the application should call **link** (),
    which will notice that the program has already been specified and linked,
    allowing other operations to be performed on the shader program. The shader
    program's id can be explicitly created using the **create** () function.

    **Caching Program Binaries**

    As of Qt 5.9, support for caching program binaries on disk is built in. To
    enable this, switch to using **addCacheableShaderFromSourceCode** () and
    **addCacheableShaderFromSourceFile** (). With an OpenGL ES 3.x context or
    support for `GL_ARB_get_program_binary`, this will transparently cache
    program binaries under **QStandardPaths::GenericCacheLocation**  or
    **QStandardPaths::CacheLocation** . When support is not available, calling
    the cacheable function variants is equivalent to the normal ones.

    **Note:** Some drivers do not have any binary formats available, even though
    they advertise the extension or offer OpenGL ES 3.0. In this case program
    binary support will be disabled.

    **See also** **QOpenGLShader** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#QOpenGLShaderProgram

        **QOpenGLShaderProgram::QOpenGLShaderProgram(QObject * parent =
        nullptr)**

        Constructs a new shader program and attaches it to **parent**. The
        program will be invalid until **addShader** () is called.

        The shader program will be associated with the current
        **QOpenGLContext** .

        **See also** **addShader** ().
        """
        ...

    def addCacheableShaderFromSourceFile(
        self, type: QOpenGLShader.ShaderTypeBit, fileName: str
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#addCacheableShaderFromS
        ourceFile

        **[since 5.9] bool QOpenGLShaderProgram::addCacheableShaderFromSourceFil
        e(QOpenGLShader::ShaderType type , const QString & fileName )**

        Registers the shader of the specified **type** and **fileName** to this
        program. Unlike **addShaderFromSourceFile** (), this function does not
        perform compilation. Compilation is deferred to **link** (), and may not
        happen at all, because **link** () may potentially use a program binary
        from Qt's shader disk cache. This will typically lead to a significant
        increase in performance.

        Returns true if the file has been read successfully, false if the file
        could not be opened or the normal, non-cached compilation of the shader
        has failed. The compilation error messages can be retrieved via **log**
        ().

        When the disk cache is disabled, via **Qt::AA_DisableShaderDiskCache**
        for example, or the OpenGL context has no support for context binaries,
        calling this function is equivalent to **addShaderFromSourceFile** ().

        This function was introduced in Qt 5.9.

        **See also** **addShaderFromSourceFile** () and
        **addCacheableShaderFromSourceCode** ().
        """
        ...

    @typing.overload
    def addCacheableShaderFromSourceCode(
        self, type: QOpenGLShader.ShaderTypeBit, source: QtCore.QByteArray
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#addCacheableShaderFromS
        ourceCode

        **[since 5.9] bool QOpenGLShaderProgram::addCacheableShaderFromSourceCod
        e(QOpenGLShader::ShaderType type , const char * source )**

        Registers the shader of the specified **type** and **source** to this
        program. Unlike **addShaderFromSourceCode** (), this function does not
        perform compilation. Compilation is deferred to **link** (), and may not
        happen at all, because **link** () may potentially use a program binary
        from Qt's shader disk cache. This will typically lead to a significant
        increase in performance.

        Returns true if the shader has been registered or, in the non-cached
        case, compiled successfully; false if there was an error. The
        compilation error messages can be retrieved via **log** ().

        When the disk cache is disabled, via **Qt::AA_DisableShaderDiskCache**
        for example, or the OpenGL context has no support for context binaries,
        calling this function is equivalent to **addShaderFromSourceCode** ().

        This function was introduced in Qt 5.9.

        **See also** **addShaderFromSourceCode** () and
        **addCacheableShaderFromSourceFile** ().
        """
        ...

    @typing.overload
    def addCacheableShaderFromSourceCode(
        self, type: QOpenGLShader.ShaderTypeBit, source: str
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#addCacheableShaderFromS
        ourceCode-1

        **[since 5.9] bool QOpenGLShaderProgram::addCacheableShaderFromSourceCod
        e(QOpenGLShader::ShaderType type , const QByteArray & source )**

        This is an overloaded function.

        Registers the shader of the specified **type** and **source** to this
        program. Unlike **addShaderFromSourceCode** (), this function does not
        perform compilation. Compilation is deferred to **link** (), and may not
        happen at all, because **link** () may potentially use a program binary
        from Qt's shader disk cache. This will typically lead to a significant
        increase in performance.

        Returns true if the shader has been registered or, in the non-cached
        case, compiled successfully; false if there was an error. The
        compilation error messages can be retrieved via **log** ().

        When the disk cache is disabled, via **Qt::AA_DisableShaderDiskCache**
        for example, or the OpenGL context has no support for context binaries,
        calling this function is equivalent to **addShaderFromSourceCode** ().

        This function was introduced in Qt 5.9.

        **See also** **addShaderFromSourceCode** () and
        **addCacheableShaderFromSourceFile** ().
        """
        ...

    def create(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#create

        **[since 5.3] bool QOpenGLShaderProgram::create()**

        Requests the shader program's id to be created immediately. Returns
        `true` if successful; `false` otherwise.

        This function is primarily useful when combining
        **QOpenGLShaderProgram**  with other OpenGL functions that operate
        directly on the shader program id, like `GL_OES_get_program_binary`.

        When the shader program is used normally, the shader program's id will
        be created on demand.

        This function was introduced in Qt 5.3.

        **See also** **programId** ().
        """
        ...

    def defaultInnerTessellationLevels(self) -> typing.List[float]:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#defaultInnerTessellatio
        nLevels

        **QList<float> QOpenGLShaderProgram::defaultInnerTessellationLevels()
        const**

        Returns the default inner tessellation levels to be used by the
        tessellation primitive generator in the event that the tessellation
        control shader does not output them. For more details on OpenGL and
        Tessellation shaders see **OpenGL Tessellation Shaders** .

        Returns a **QList**  of floats describing the inner tessellation levels.
        The vector will always have two elements but not all of them make sense
        for every mode of tessellation.

        **Note:** This returns the global OpenGL state value. It is not specific
        to this **QOpenGLShaderProgram**  instance.

        **Note:** This function is only supported with OpenGL >= 4.0 and will
        not return valid results with OpenGL ES 3.2.

        **See also** **setDefaultInnerTessellationLevels** () and
        **defaultOuterTessellationLevels** ().
        """
        ...

    def setDefaultInnerTessellationLevels(self, levels: typing.Iterable[float]) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setDefaultInnerTessella
        tionLevels

        **void QOpenGLShaderProgram::setDefaultInnerTessellationLevels(const
        QList<float> & levels )**

        Sets the default outer tessellation levels to be used by the
        tessellation primitive generator in the event that the tessellation
        control shader does not output them to **levels**. For more details on
        OpenGL and Tessellation shaders see **OpenGL Tessellation Shaders** .

        The **levels** argument should be a **QList**  consisting of 2 floats.
        Not all of the values make sense for all tessellation modes. If you
        specify a vector with fewer than 2 elements, the remaining elements will
        be given a default value of 1.

        **Note:** This modifies global OpenGL state and is not specific to this
        **QOpenGLShaderProgram**  instance. You should call this in your render
        function when needed, as **QOpenGLShaderProgram**  will not apply this
        for you. This is purely a convenience function.

        **Note:** This function is only available with OpenGL >= 4.0 and is not
        supported with OpenGL ES 3.2.

        **See also** **defaultInnerTessellationLevels** () and
        **setDefaultOuterTessellationLevels** ().
        """
        ...

    def defaultOuterTessellationLevels(self) -> typing.List[float]:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#defaultOuterTessellatio
        nLevels

        **QList<float> QOpenGLShaderProgram::defaultOuterTessellationLevels()
        const**

        Returns the default outer tessellation levels to be used by the
        tessellation primitive generator in the event that the tessellation
        control shader does not output them. For more details on OpenGL and
        Tessellation shaders see **OpenGL Tessellation Shaders** .

        Returns a **QList**  of floats describing the outer tessellation levels.
        The vector will always have four elements but not all of them make sense
        for every mode of tessellation.

        **Note:** This returns the global OpenGL state value. It is not specific
        to this **QOpenGLShaderProgram**  instance.

        **Note:** This function is only supported with OpenGL >= 4.0 and will
        not return valid results with OpenGL ES 3.2.

        **See also** **setDefaultOuterTessellationLevels** () and
        **defaultInnerTessellationLevels** ().
        """
        ...

    def setDefaultOuterTessellationLevels(self, levels: typing.Iterable[float]) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setDefaultOuterTessella
        tionLevels

        **void QOpenGLShaderProgram::setDefaultOuterTessellationLevels(const
        QList<float> & levels )**

        Sets the default outer tessellation levels to be used by the
        tessellation primitive generator in the event that the tessellation
        control shader does not output them to **levels**. For more details on
        OpenGL and Tessellation shaders see **OpenGL Tessellation Shaders** .

        The **levels** argument should be a **QList**  consisting of 4 floats.
        Not all of the values make sense for all tessellation modes. If you
        specify a vector with fewer than 4 elements, the remaining elements will
        be given a default value of 1.

        **Note:** This modifies global OpenGL state and is not specific to this
        **QOpenGLShaderProgram**  instance. You should call this in your render
        function when needed, as **QOpenGLShaderProgram**  will not apply this
        for you. This is purely a convenience function.

        **Note:** This function is only available with OpenGL >= 4.0 and is not
        supported with OpenGL ES 3.2.

        **See also** **defaultOuterTessellationLevels** () and
        **setDefaultInnerTessellationLevels** ().
        """
        ...

    def patchVertexCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#patchVertexCount

        **int QOpenGLShaderProgram::patchVertexCount() const**

        Returns the number of vertices per-patch to be used when rendering.

        **Note:** This returns the global OpenGL state value. It is not specific
        to this **QOpenGLShaderProgram**  instance.

        **See also** **setPatchVertexCount** ().
        """
        ...

    def setPatchVertexCount(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setPatchVertexCount

        **void QOpenGLShaderProgram::setPatchVertexCount(int count )**

        Use this function to specify to OpenGL the number of vertices in a patch
        to **count**. A patch is a custom OpenGL primitive whose interpretation
        is entirely defined by the tessellation shader stages. Therefore,
        calling this function only makes sense when using a
        **QOpenGLShaderProgram**  containing tessellation stage shaders. When
        using OpenGL tessellation, the only primitive that can be rendered with
        `glDraw*()` functions is `GL_PATCHES`.

        This is equivalent to calling glPatchParameteri(GL_PATCH_VERTICES,
        count).

        **Note:** This modifies global OpenGL state and is not specific to this
        **QOpenGLShaderProgram**  instance. You should call this in your render
        function when needed, as **QOpenGLShaderProgram**  will not apply this
        for you. This is purely a convenience function.

        **See also** **patchVertexCount** ().
        """
        ...

    def maxGeometryOutputVertices(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#maxGeometryOutputVertic
        es

        **int QOpenGLShaderProgram::maxGeometryOutputVertices() const**

        Returns the hardware limit for how many vertices a geometry shader can
        output.
        """
        ...

    @staticmethod
    def hasOpenGLShaderPrograms(
        context: typing.Optional[QtGui.QOpenGLContext] = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#hasOpenGLShaderPrograms

        **[static] bool
        QOpenGLShaderProgram::hasOpenGLShaderPrograms(QOpenGLContext * context =
        nullptr)**

        Returns `true` if shader programs written in the OpenGL Shading Language
        (GLSL) are supported on this system; false otherwise.

        The **context** is used to resolve the GLSL extensions. If **context**
        is `nullptr`, then **QOpenGLContext::currentContext** () is used.
        """
        ...

    @typing.overload
    def setUniformValueArray(
        self, location: int, values: PYQT_SHADER_UNIFORM_VALUE_ARRAY
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValueArray

        **void QOpenGLShaderProgram::setUniformValueArray(int location , const
        GLfloat * values , int count , int tupleSize )**

        Sets the uniform variable array at **location** in the current context
        to the **count** elements of **values**. Each element has **tupleSize**
        components. The **tupleSize** must be 1, 2, 3, or 4.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValueArray(
        self, name: str, values: PYQT_SHADER_UNIFORM_VALUE_ARRAY
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValueArray-1

        **void QOpenGLShaderProgram::setUniformValueArray(int location , const
        GLint * values , int count )**

        Sets the uniform variable array at **location** in the current context
        to the **count** elements of **values**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-1

        **void QOpenGLShaderProgram::setUniformValue(int location , GLint value
        )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-2

        **void QOpenGLShaderProgram::setUniformValue(int location , GLuint value
        )**

        Sets the uniform variable at **location** in the current context to
        **value**. This function should be used when setting sampler values.

        **Note:** This function is not aware of unsigned int support in modern
        OpenGL versions and therefore treats **value** as a GLint and calls
        glUniform1i.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, x: float, y: float, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-3

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat x ,
        GLfloat y )**

        Sets the uniform variable at **location** in the current context to the
        2D vector ( **x** , **y** ).

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(
        self, location: int, x: float, y: float, z: float, w: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-4

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat x ,
        GLfloat y , GLfloat z )**

        Sets the uniform variable at **location** in the current context to the
        3D vector ( **x** , **y** , **z** ).

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QVector2D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-5

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat x ,
        GLfloat y , GLfloat z , GLfloat w )**

        Sets the uniform variable at **location** in the current context to the
        4D vector ( **x** , **y** , **z** , **w** ).

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-6

        **void QOpenGLShaderProgram::setUniformValue(int location , const
        QVector2D & value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QVector4D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-7

        **void QOpenGLShaderProgram::setUniformValue(int location , const
        QVector3D & value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(
        self,
        location: int,
        color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-8

        **void QOpenGLShaderProgram::setUniformValue(int location , const
        QVector4D & value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, point: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-9

        **void QOpenGLShaderProgram::setUniformValue(int location , const QColor
        & color )**

        Sets the uniform variable at **location** in the current context to the
        red, green, blue, and alpha components of **color**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, point: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue-10

        **void QOpenGLShaderProgram::setUniformValue(int location , const QPoint
        & point )**

        Sets the uniform variable at **location** in the current context to the
        x and y coordinates of **point**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix2x2) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix2x3) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix2x4) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix3x2) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix3x3) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix3x4) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix4x2) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix4x3) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QMatrix4x4) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, location: int, value: QtGui.QTransform) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, x: float, y: float, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(
        self, name: str, x: float, y: float, z: float, w: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QVector2D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QVector4D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(
        self, name: str, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, point: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, point: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix2x2) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix2x3) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix2x4) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix3x2) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix3x3) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix3x4) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix4x2) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix4x3) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QMatrix4x4) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def setUniformValue(self, name: str, value: QtGui.QTransform) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setUniformValue

        **void QOpenGLShaderProgram::setUniformValue(int location , GLfloat
        value )**

        Sets the uniform variable at **location** in the current context to
        **value**.

        **See also** **setAttributeValue** ().
        """
        ...

    @typing.overload
    def uniformLocation(self, name: QtCore.QByteArray) -> int:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#uniformLocation

        **int QOpenGLShaderProgram::uniformLocation(const char * name ) const**

        Returns the location of the uniform variable **name** within this shader
        program's parameter list. Returns -1 if **name** is not a valid uniform
        variable for this shader program.

        **See also** **attributeLocation** ().
        """
        ...

    @typing.overload
    def uniformLocation(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#uniformLocation-1

        **int QOpenGLShaderProgram::uniformLocation(const QByteArray & name )
        const**

        This is an overloaded function.

        Returns the location of the uniform variable **name** within this shader
        program's parameter list. Returns -1 if **name** is not a valid uniform
        variable for this shader program.

        **See also** **attributeLocation** ().
        """
        ...

    @typing.overload
    def disableAttributeArray(self, location: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#disableAttributeArray

        **void QOpenGLShaderProgram::disableAttributeArray(int location )**

        Disables the vertex array at **location** in this shader program that
        was enabled by a previous call to **enableAttributeArray** ().

        **See also** **enableAttributeArray** (), **setAttributeArray** (),
        **setAttributeValue** (), and **setUniformValue** ().
        """
        ...

    @typing.overload
    def disableAttributeArray(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#disableAttributeArray-1

        **void QOpenGLShaderProgram::disableAttributeArray(const char * name )**

        This is an overloaded function.

        Disables the vertex array called **name** in this shader program that
        was enabled by a previous call to **enableAttributeArray** ().

        **See also** **enableAttributeArray** (), **setAttributeArray** (),
        **setAttributeValue** (), and **setUniformValue** ().
        """
        ...

    @typing.overload
    def enableAttributeArray(self, location: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#enableAttributeArray

        **void QOpenGLShaderProgram::enableAttributeArray(int location )**

        Enables the vertex array at **location** in this shader program so that
        the value set by **setAttributeArray** () on **location** will be used
        by the shader program.

        **See also** **disableAttributeArray** (), **setAttributeArray** (),
        **setAttributeValue** (), and **setUniformValue** ().
        """
        ...

    @typing.overload
    def enableAttributeArray(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#enableAttributeArray-1

        **void QOpenGLShaderProgram::enableAttributeArray(const char * name )**

        This is an overloaded function.

        Enables the vertex array called **name** in this shader program so that
        the value set by **setAttributeArray** () on **name** will be used by
        the shader program.

        **See also** **disableAttributeArray** (), **setAttributeArray** (),
        **setAttributeValue** (), and **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeBuffer(
        self, location: int, type: int, offset: int, tupleSize: int, stride: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeBuffer

        **void QOpenGLShaderProgram::setAttributeBuffer(int location , GLenum
        type , int offset , int tupleSize , int stride = 0)**

        Sets an array of vertex values on the attribute at **location** in this
        shader program, starting at a specific **offset** in the currently bound
        vertex buffer. The **stride** indicates the number of bytes between
        vertices. A default **stride** value of zero indicates that the vertices
        are densely packed in the value array.

        The **type** indicates the type of elements in the vertex value array,
        usually `GL_FLOAT`, `GL_UNSIGNED_BYTE`, etc. The **tupleSize** indicates
        the number of components per vertex: 1, 2, 3, or 4.

        The array will become active when **enableAttributeArray** () is called
        on the **location**. Otherwise the value specified with
        **setAttributeValue** () for **location** will be used.

        **Note:** Normalization will be enabled. If this is not desired, call
        glVertexAttribPointer directly through **QOpenGLFunctions** .

        **See also** **setAttributeArray** ().
        """
        ...

    @typing.overload
    def setAttributeBuffer(
        self, name: str, type: int, offset: int, tupleSize: int, stride: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeBuffer-1

        **void QOpenGLShaderProgram::setAttributeBuffer(const char * name ,
        GLenum type , int offset , int tupleSize , int stride = 0)**

        This is an overloaded function.

        Sets an array of vertex values on the attribute called **name** in this
        shader program, starting at a specific **offset** in the currently bound
        vertex buffer. The **stride** indicates the number of bytes between
        vertices. A default **stride** value of zero indicates that the vertices
        are densely packed in the value array.

        The **type** indicates the type of elements in the vertex value array,
        usually `GL_FLOAT`, `GL_UNSIGNED_BYTE`, etc. The **tupleSize** indicates
        the number of components per vertex: 1, 2, 3, or 4.

        The array will become active when **enableAttributeArray** () is called
        on the **name**. Otherwise the value specified with
        **setAttributeValue** () for **name** will be used.

        **See also** **setAttributeArray** ().
        """
        ...

    @typing.overload
    def setAttributeArray(
        self, location: int, values: PYQT_SHADER_ATTRIBUTE_ARRAY
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeArray

        **void QOpenGLShaderProgram::setAttributeArray(int location , const
        GLfloat * values , int tupleSize , int stride = 0)**

        Sets an array of vertex **values** on the attribute at **location** in
        this shader program. The **tupleSize** indicates the number of
        components per vertex (1, 2, 3, or 4), and the **stride** indicates the
        number of bytes between vertices. A default **stride** value of zero
        indicates that the vertices are densely packed in **values**.

        The array will become active when **enableAttributeArray** () is called
        on the **location**. Otherwise the value specified with
        **setAttributeValue** () for **location** will be used.

        **See also** **setAttributeValue** (), **setUniformValue** (),
        **enableAttributeArray** (), and **disableAttributeArray** ().
        """
        ...

    @typing.overload
    def setAttributeArray(self, name: str, values: PYQT_SHADER_ATTRIBUTE_ARRAY) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeArray-1

        **void QOpenGLShaderProgram::setAttributeArray(int location , const
        QVector2D * values , int stride = 0)**

        Sets an array of 2D vertex **values** on the attribute at **location**
        in this shader program. The **stride** indicates the number of bytes
        between vertices. A default **stride** value of zero indicates that the
        vertices are densely packed in **values**.

        The array will become active when **enableAttributeArray** () is called
        on the **location**. Otherwise the value specified with
        **setAttributeValue** () for **location** will be used.

        **See also** **setAttributeValue** (), **setUniformValue** (),
        **enableAttributeArray** (), and **disableAttributeArray** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, location: int, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat
        value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, location: int, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-1

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat x
        , GLfloat y )**

        Sets the attribute at **location** in the current context to the 2D
        vector ( **x** , **y** ).

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, location: int, x: float, y: float, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-2

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat x
        , GLfloat y , GLfloat z )**

        Sets the attribute at **location** in the current context to the 3D
        vector ( **x** , **y** , **z** ).

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(
        self, location: int, x: float, y: float, z: float, w: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-3

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat x
        , GLfloat y , GLfloat z , GLfloat w )**

        Sets the attribute at **location** in the current context to the 4D
        vector ( **x** , **y** , **z** , **w** ).

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, location: int, value: QtGui.QVector2D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-4

        **void QOpenGLShaderProgram::setAttributeValue(int location , const
        QVector2D & value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, location: int, value: QtGui.QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-5

        **void QOpenGLShaderProgram::setAttributeValue(int location , const
        QVector3D & value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, location: int, value: QtGui.QVector4D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-6

        **void QOpenGLShaderProgram::setAttributeValue(int location , const
        QVector4D & value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(
        self,
        location: int,
        value: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-7

        **void QOpenGLShaderProgram::setAttributeValue(int location , const
        QColor & value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, name: str, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-8

        **void QOpenGLShaderProgram::setAttributeValue(int location , const
        GLfloat * values , int columns , int rows )**

        Sets the attribute at **location** in the current context to the
        contents of **values** , which contains **columns** elements, each
        consisting of **rows** elements. The **rows** value should be 1, 2, 3,
        or 4. This function is typically used to set matrix values and column
        vectors.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, name: str, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-9

        **void QOpenGLShaderProgram::setAttributeValue(const char * name ,
        GLfloat value )**

        This is an overloaded function.

        Sets the attribute called **name** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, name: str, x: float, y: float, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue-10

        **void QOpenGLShaderProgram::setAttributeValue(const char * name ,
        GLfloat x , GLfloat y )**

        This is an overloaded function.

        Sets the attribute called **name** in the current context to the 2D
        vector ( **x** , **y** ).

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(
        self, name: str, x: float, y: float, z: float, w: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat
        value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, name: str, value: QtGui.QVector2D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat
        value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, name: str, value: QtGui.QVector3D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat
        value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(self, name: str, value: QtGui.QVector4D) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat
        value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def setAttributeValue(
        self, name: str, value: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#setAttributeValue

        **void QOpenGLShaderProgram::setAttributeValue(int location , GLfloat
        value )**

        Sets the attribute at **location** in the current context to **value**.

        **See also** **setUniformValue** ().
        """
        ...

    @typing.overload
    def attributeLocation(self, name: QtCore.QByteArray) -> int:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#attributeLocation

        **int QOpenGLShaderProgram::attributeLocation(const char * name )
        const**

        Returns the location of the attribute **name** within this shader
        program's parameter list. Returns -1 if **name** is not a valid
        attribute for this shader program.

        **See also** **uniformLocation** () and **bindAttributeLocation** ().
        """
        ...

    @typing.overload
    def attributeLocation(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#attributeLocation-1

        **int QOpenGLShaderProgram::attributeLocation(const QByteArray & name )
        const**

        This is an overloaded function.

        Returns the location of the attribute **name** within this shader
        program's parameter list. Returns -1 if **name** is not a valid
        attribute for this shader program.

        **See also** **uniformLocation** () and **bindAttributeLocation** ().
        """
        ...

    @typing.overload
    def bindAttributeLocation(self, name: QtCore.QByteArray, location: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#bindAttributeLocation

        **void QOpenGLShaderProgram::bindAttributeLocation(const char * name ,
        int location )**

        Binds the attribute **name** to the specified **location**. This
        function can be called before or after the program has been linked. Any
        attributes that have not been explicitly bound when the program is
        linked will be assigned locations automatically.

        When this function is called after the program has been linked, the
        program will need to be relinked for the change to take effect.

        **See also** **attributeLocation** ().
        """
        ...

    @typing.overload
    def bindAttributeLocation(self, name: str, location: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#bindAttributeLocation-1

        **void QOpenGLShaderProgram::bindAttributeLocation(const QByteArray &
        name , int location )**

        This is an overloaded function.

        Binds the attribute **name** to the specified **location**. This
        function can be called before or after the program has been linked. Any
        attributes that have not been explicitly bound when the program is
        linked will be assigned locations automatically.

        When this function is called after the program has been linked, the
        program will need to be relinked for the change to take effect.

        **See also** **attributeLocation** ().
        """
        ...

    def programId(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#programId

        **GLuint QOpenGLShaderProgram::programId() const**

        Returns the OpenGL identifier associated with this shader program.

        **See also** **QOpenGLShader::shaderId** ().
        """
        ...

    def release(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#release

        **void QOpenGLShaderProgram::release()**

        Releases the active shader program from the current **QOpenGLContext** .
        This is equivalent to calling `glUseProgram(0)`.

        **See also** **bind** ().
        """
        ...

    def bind(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#bind

        **bool QOpenGLShaderProgram::bind()**

        Binds this shader program to the active **QOpenGLContext**  and makes it
        the current shader program. Any previously bound shader program is
        released. This is equivalent to calling `glUseProgram()` on
        **programId** (). Returns `true` if the program was successfully bound;
        false otherwise. If the shader program has not yet been linked, or it
        needs to be re-linked, this function will call **link** ().

        **See also** **link** () and **release** ().
        """
        ...

    def log(self) -> str:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#log

        **QString QOpenGLShaderProgram::log() const**

        Returns the errors and warnings that occurred during the last **link**
        () or **addShader** () with explicitly specified source code.

        **See also** **link** ().
        """
        ...

    def isLinked(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#isLinked

        **bool QOpenGLShaderProgram::isLinked() const**

        Returns `true` if this shader program has been linked; false otherwise.

        **See also** **link** ().
        """
        ...

    def link(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#link

        **[virtual] bool QOpenGLShaderProgram::link()**

        Links together the shaders that were added to this program with
        **addShader** (). Returns `true` if the link was successful or false
        otherwise. If the link failed, the error messages can be retrieved with
        **log** ().

        Subclasses can override this function to initialize attributes and
        uniform variables for use in specific shader programs.

        If the shader program was already linked, calling this function again
        will force it to be re-linked.

        When shaders were added to this program via
        **addCacheableShaderFromSourceCode** () or
        **addCacheableShaderFromSourceFile** (), program binaries are supported,
        and a cached binary is available on disk, actual compilation and linking
        are skipped. Instead, link() will initialize the program with the binary
        blob via glProgramBinary(). If there is no cached version of the program
        or it was generated with a different driver version, the shaders will be
        compiled from source and the program will get linked normally. This
        allows seamless upgrading of the graphics drivers, without having to
        worry about potentially incompatible binary formats.

        **See also** **addShader** () and **log** ().
        """
        ...

    def removeAllShaders(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#removeAllShaders

        **void QOpenGLShaderProgram::removeAllShaders()**

        Removes all of the shaders that were added to this program previously.
        The **QOpenGLShader**  objects for the shaders will not be deleted if
        they were constructed externally. **QOpenGLShader**  objects that are
        constructed internally by **QOpenGLShaderProgram**  will be deleted.

        **See also** **addShader** () and **removeShader** ().
        """
        ...

    def addShaderFromSourceFile(
        self, type: QOpenGLShader.ShaderTypeBit, fileName: str
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#addShaderFromSourceFile

        **bool
        QOpenGLShaderProgram::addShaderFromSourceFile(QOpenGLShader::ShaderType
        type , const QString & fileName )**

        Compiles the contents of **fileName** as a shader of the specified
        **type** and adds it to this shader program. Returns `true` if
        compilation was successful, false otherwise. The compilation errors and
        warnings will be made available via **log** ().

        This function is intended to be a short-cut for quickly adding vertex
        and fragment shaders to a shader program without creating an instance of
        **QOpenGLShader**  first.

        **See also** **addShader** () and **addShaderFromSourceCode** ().
        """
        ...

    @typing.overload
    def addShaderFromSourceCode(
        self, type: QOpenGLShader.ShaderTypeBit, source: QtCore.QByteArray
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#addShaderFromSourceCode

        **bool
        QOpenGLShaderProgram::addShaderFromSourceCode(QOpenGLShader::ShaderType
        type , const char * source )**

        Compiles **source** as a shader of the specified **type** and adds it to
        this shader program. Returns `true` if compilation was successful, false
        otherwise. The compilation errors and warnings will be made available
        via **log** ().

        This function is intended to be a short-cut for quickly adding vertex
        and fragment shaders to a shader program without creating an instance of
        **QOpenGLShader**  first.

        **See also** **addShader** (), **addShaderFromSourceFile** (),
        **removeShader** (), **link** (), **log** (), and **removeAllShaders**
        ().
        """
        ...

    @typing.overload
    def addShaderFromSourceCode(
        self, type: QOpenGLShader.ShaderTypeBit, source: str
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#addShaderFromSourceCode
        -1

        **bool
        QOpenGLShaderProgram::addShaderFromSourceCode(QOpenGLShader::ShaderType
        type , const QByteArray & source )**

        This is an overloaded function.

        Compiles **source** as a shader of the specified **type** and adds it to
        this shader program. Returns `true` if compilation was successful, false
        otherwise. The compilation errors and warnings will be made available
        via **log** ().

        This function is intended to be a short-cut for quickly adding vertex
        and fragment shaders to a shader program without creating an instance of
        **QOpenGLShader**  first.

        **See also** **addShader** (), **addShaderFromSourceFile** (),
        **removeShader** (), **link** (), **log** (), and **removeAllShaders**
        ().
        """
        ...

    def shaders(self) -> typing.List[QOpenGLShader]:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#shaders

        **QList<QOpenGLShader *> QOpenGLShaderProgram::shaders() const**

        Returns a list of all shaders that have been added to this shader
        program using **addShader** ().

        **See also** **addShader** () and **removeShader** ().
        """
        ...

    def removeShader(self, shader: QOpenGLShader) -> None:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#removeShader

        **void QOpenGLShaderProgram::removeShader(QOpenGLShader * shader )**

        Removes **shader** from this shader program. The object is not deleted.

        The shader program must be valid in the current **QOpenGLContext** .

        **See also** **addShader** (), **link** (), and **removeAllShaders** ().
        """
        ...

    def addShader(self, shader: QOpenGLShader) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglshaderprogram.html#addShader

        **bool QOpenGLShaderProgram::addShader(QOpenGLShader * shader )**

        Adds a compiled **shader** to this shader program. Returns `true` if the
        shader could be added, or false otherwise.

        Ownership of the **shader** object remains with the caller. It will not
        be deleted when this **QOpenGLShaderProgram**  instance is deleted. This
        allows the caller to add the same shader to multiple shader programs.

        **See also** **addShaderFromSourceCode** (), **addShaderFromSourceFile**
        (), **removeShader** (), **link** (), and **removeAllShaders** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QMetaMethod(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmetamethod.html

    **Detailed Description**

    A QMetaMethod has a **methodType** (), a **methodSignature** (), a list of
    **parameterTypes** () and **parameterNames** (), a return **typeName** (), a
    **tag** (), and an **access** () specifier. You can use **invoke** () to
    invoke the method on an arbitrary **QObject** .

    **See also** **QMetaObject** , **QMetaEnum** , **QMetaProperty** , and
    **Qt's Property System** .
    """

    class MethodType(enum.Enum):
        Method: QMetaMethod = ...
        Signal: QMetaMethod = ...
        Slot: QMetaMethod = ...
        Constructor: QMetaMethod = ...

    class Access(enum.Enum):
        Private: QMetaMethod = ...
        Protected: QMetaMethod = ...
        Public: QMetaMethod = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QMetaMethod") -> None:
        ...

    def isConst(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#isConst

        **[since 6.2] bool QMetaMethod::isConst() const**

        Returns whether the method is const qualified.

        **Note:** This method might erroneously return `false` for a const
        method if it belongs to a library compiled against an older version of
        Qt.

        This function was introduced in Qt 6.2.
        """
        ...

    def relativeMethodIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#relativeMethodIndex

        **[since 6.0] int QMetaMethod::relativeMethodIndex() const**

        Returns this method's local index inside.

        This function was introduced in Qt 6.0.
        """
        ...

    def parameterTypeName(self, index: int) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#parameterTypeName

        **[since 6.0] QByteArray QMetaMethod::parameterTypeName(int index )
        const**

        Returns the name of the type at position **index** If there is no
        parameter at **index** , returns an empty **QByteArray**

        This function was introduced in Qt 6.0.

        **See also** **parameterNames** ().
        """
        ...

    def parameterMetaType(self, index: int) -> "QMetaType":
        """
        https://doc.qt.io/qt-6/qmetamethod.html#parameterMetaType

        **[since 6.0] QMetaType QMetaMethod::parameterMetaType(int index )
        const**

        Returns the metatype of the parameter at the given **index**.

        If the **index** is smaller than zero or larger than **parameterCount**
        (), an invalid **QMetaType**  is returned.

        This function was introduced in Qt 6.0.

        **See also** **parameterCount** (), **returnMetaType** (), and
        **QMetaType** .
        """
        ...

    def returnMetaType(self) -> "QMetaType":
        """
        https://doc.qt.io/qt-6/qmetamethod.html#returnMetaType

        **[since 6.0] QMetaType QMetaMethod::returnMetaType() const**

        Returns the return type of this method.

        This function was introduced in Qt 6.0.

        **See also** **parameterMetaType** (), **QMetaType** , and **typeName**
        ().
        """
        ...

    def parameterType(self, index: int) -> int:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#parameterType

        **[since 5.0] int QMetaMethod::parameterType(int index ) const**

        Returns the type of the parameter at the given **index**.

        The return value is one of the types that are registered with
        **QMetaType** , or **QMetaType::UnknownType**  if the type is not
        registered.

        This function was introduced in Qt 5.0.

        **See also** **parameterCount** (), **parameterMetaType** (),
        **returnType** (), and **QMetaType** .
        """
        ...

    def parameterCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#parameterCount

        **[since 5.0] int QMetaMethod::parameterCount() const**

        Returns the number of parameters of this method.

        This function was introduced in Qt 5.0.

        **See also** **parameterType** () and **parameterNames** ().
        """
        ...

    def returnType(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#returnType

        **[since 5.0] int QMetaMethod::returnType() const**

        Returns the return type of this method.

        The return value is one of the types that are registered with
        **QMetaType** , or **QMetaType::UnknownType**  if the type is not
        registered.

        This function was introduced in Qt 5.0.

        **See also** **parameterType** (), **QMetaType** , **typeName** (), and
        **returnMetaType** ().
        """
        ...

    def name(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#name

        **[since 5.0] QByteArray QMetaMethod::name() const**

        Returns the name of this method.

        This function was introduced in Qt 5.0.

        **See also** **methodSignature** () and **parameterCount** ().
        """
        ...

    def methodSignature(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#methodSignature

        **[since 5.0] QByteArray QMetaMethod::methodSignature() const**

        Returns the signature of this method (e.g., `setValue(double)`).

        This function was introduced in Qt 5.0.

        **See also** **parameterTypes** () and **parameterNames** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#isValid

        **[since 5.0] bool QMetaMethod::isValid() const**

        Returns `true` if this method is valid (can be introspected and
        invoked), otherwise returns `false`.

        This function was introduced in Qt 5.0.
        """
        ...

    def methodIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#methodIndex

        **int QMetaMethod::methodIndex() const**

        Returns this method's index.
        """
        ...

    @typing.overload
    def invoke(
        self,
        object: QObject,
        value0: "QGenericArgument" = ...,
        value1: "QGenericArgument" = ...,
        value2: "QGenericArgument" = ...,
        value3: "QGenericArgument" = ...,
        value4: "QGenericArgument" = ...,
        value5: "QGenericArgument" = ...,
        value6: "QGenericArgument" = ...,
        value7: "QGenericArgument" = ...,
        value8: "QGenericArgument" = ...,
        value9: "QGenericArgument" = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#invoke

        **bool QMetaMethod::invoke(QObject * object , Qt::ConnectionType
        connectionType , QGenericReturnArgument returnValue , QGenericArgument
        val0 = QGenericArgument(nullptr), QGenericArgument val1 =
        QGenericArgument(), QGenericArgument val2 = QGenericArgument(),
        QGenericArgument val3 = QGenericArgument(), QGenericArgument val4 =
        QGenericArgument(), QGenericArgument val5 = QGenericArgument(),
        QGenericArgument val6 = QGenericArgument(), QGenericArgument val7 =
        QGenericArgument(), QGenericArgument val8 = QGenericArgument(),
        QGenericArgument val9 = QGenericArgument()) const**

        Invokes this method on the object **object**. Returns `true` if the
        member could be invoked. Returns `false` if there is no such member or
        the parameters did not match.

        The invocation can be either synchronous or asynchronous, depending on
        the **connectionType** :

        * If **connectionType** is **Qt::DirectConnection** , the member will be
        invoked immediately.
          * If **connectionType** is
        **Qt::QueuedConnection** , a **QEvent**  will be posted and the member
        is invoked as soon as the application enters the main event loop.
          * If
        **connectionType** is **Qt::AutoConnection** , the member is invoked
        synchronously if **object** lives in the same thread as the caller;
        otherwise it will invoke the member asynchronously.

        The return value of this method call is placed in **returnValue**. If
        the invocation is asynchronous, the return value cannot be evaluated.
        You can pass up to ten arguments ( **val0** , **val1** , **val2** ,
        **val3** , **val4** , **val5** , **val6** , **val7** , **val8** , and
        **val9** ) to this method call.

        **QGenericArgument**  and **QGenericReturnArgument**  are internal
        helper classes. Because signals and slots can be dynamically invoked,
        you must enclose the arguments using the **Q_ARG** () and
        **Q_RETURN_ARG** () macros. **Q_ARG** () takes a type name and a const
        reference of that type; **Q_RETURN_ARG** () takes a type name and a non-
        const reference.

        To asynchronously invoke the **animateClick** () slot on a
        **QPushButton** :

        int methodIndex =
        pushButton->metaObject()->indexOfMethod("animateClick()");
        QMetaMethod method = metaObject->method(methodIndex);
        method.invoke(pushButton, Qt::QueuedConnection);

        With asynchronous method invocations, the parameters must be of types
        that are known to Qt's meta-object system, because Qt needs to copy the
        arguments to store them in an event behind the scenes. If you try to use
        a queued connection and get the error message

        QMetaMethod::invoke: Unable to handle unregistered datatype 'MyType'

        call **qRegisterMetaType** () to register the data type before you call
        QMetaMethod::invoke().

        To synchronously invoke the `compute(QString, int, double)` slot on some
        arbitrary object `obj` retrieve its return value:

        **QString**  retVal;
            **QByteArray**  normalizedSignature =
        **QMetaObject** ::normalizedSignature("compute(QString, int, double)");
        int methodIndex = obj->metaObject()->indexOfMethod(normalizedSignature);
        QMetaMethod method = obj->metaObject()->method(methodIndex);
        method.invoke(obj,
                          Qt::DirectConnection,
        Q_RETURN_ARG(**QString** , retVal),
                          Q_ARG(**QString**
        , "sqrt"),
                          Q_ARG(int, 42),
        Q_ARG(double, 9.7));

        **QMetaObject::normalizedSignature** () is used here to ensure that the
        format of the signature is what invoke() expects. E.g. extra whitespace
        is removed.

        If the "compute" slot does not take exactly one **QString** , one int
        and one double in the specified order, the call will fail.

        **Warning:** this method will not test the validity of the arguments:
        **object** must be an instance of the class of the **QMetaObject**  of
        which this **QMetaMethod**  has been constructed with. The arguments
        must have the same type as the ones expected by the method, else, the
        behaviour is undefined.

        **See also** **Q_ARG** (), **Q_RETURN_ARG** (), **qRegisterMetaType**
        (), and **QMetaObject::invokeMethod** ().
        """
        ...

    @typing.overload
    def invoke(
        self,
        object: QObject,
        connectionType: Qt.ConnectionType,
        value0: "QGenericArgument" = ...,
        value1: "QGenericArgument" = ...,
        value2: "QGenericArgument" = ...,
        value3: "QGenericArgument" = ...,
        value4: "QGenericArgument" = ...,
        value5: "QGenericArgument" = ...,
        value6: "QGenericArgument" = ...,
        value7: "QGenericArgument" = ...,
        value8: "QGenericArgument" = ...,
        value9: "QGenericArgument" = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#invoke-1

        **bool QMetaMethod::invoke(QObject * object , QGenericReturnArgument
        returnValue , QGenericArgument val0 = QGenericArgument(0),
        QGenericArgument val1 = QGenericArgument(), QGenericArgument val2 =
        QGenericArgument(), QGenericArgument val3 = QGenericArgument(),
        QGenericArgument val4 = QGenericArgument(), QGenericArgument val5 =
        QGenericArgument(), QGenericArgument val6 = QGenericArgument(),
        QGenericArgument val7 = QGenericArgument(), QGenericArgument val8 =
        QGenericArgument(), QGenericArgument val9 = QGenericArgument()) const**

        This function overloads invoke().

        This overload always invokes this method using the connection type
        **Qt::AutoConnection** .
        """
        ...

    @typing.overload
    def invoke(
        self,
        object: QObject,
        returnValue: "QGenericReturnArgument",
        value0: "QGenericArgument" = ...,
        value1: "QGenericArgument" = ...,
        value2: "QGenericArgument" = ...,
        value3: "QGenericArgument" = ...,
        value4: "QGenericArgument" = ...,
        value5: "QGenericArgument" = ...,
        value6: "QGenericArgument" = ...,
        value7: "QGenericArgument" = ...,
        value8: "QGenericArgument" = ...,
        value9: "QGenericArgument" = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#invoke-2

        **bool QMetaMethod::invoke(QObject * object , Qt::ConnectionType
        connectionType , QGenericArgument val0 = QGenericArgument(0),
        QGenericArgument val1 = QGenericArgument(), QGenericArgument val2 =
        QGenericArgument(), QGenericArgument val3 = QGenericArgument(),
        QGenericArgument val4 = QGenericArgument(), QGenericArgument val5 =
        QGenericArgument(), QGenericArgument val6 = QGenericArgument(),
        QGenericArgument val7 = QGenericArgument(), QGenericArgument val8 =
        QGenericArgument(), QGenericArgument val9 = QGenericArgument()) const**

        This function overloads invoke().

        This overload can be used if the return value of the member is of no
        interest.
        """
        ...

    @typing.overload
    def invoke(
        self,
        object: QObject,
        connectionType: Qt.ConnectionType,
        returnValue: "QGenericReturnArgument",
        value0: "QGenericArgument" = ...,
        value1: "QGenericArgument" = ...,
        value2: "QGenericArgument" = ...,
        value3: "QGenericArgument" = ...,
        value4: "QGenericArgument" = ...,
        value5: "QGenericArgument" = ...,
        value6: "QGenericArgument" = ...,
        value7: "QGenericArgument" = ...,
        value8: "QGenericArgument" = ...,
        value9: "QGenericArgument" = ...,
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#invoke-3

        **bool QMetaMethod::invoke(QObject * object , QGenericArgument val0 =
        QGenericArgument(0), QGenericArgument val1 = QGenericArgument(),
        QGenericArgument val2 = QGenericArgument(), QGenericArgument val3 =
        QGenericArgument(), QGenericArgument val4 = QGenericArgument(),
        QGenericArgument val5 = QGenericArgument(), QGenericArgument val6 =
        QGenericArgument(), QGenericArgument val7 = QGenericArgument(),
        QGenericArgument val8 = QGenericArgument(), QGenericArgument val9 =
        QGenericArgument()) const**

        This function overloads invoke().

        This overload invokes this method using the connection type
        **Qt::AutoConnection**  and ignores return values.
        """
        ...

    def methodType(self) -> "QMetaMethod.MethodType":
        """
        https://doc.qt.io/qt-6/qmetamethod.html#methodType

        **QMetaMethod::MethodType QMetaMethod::methodType() const**

        Returns the type of this method (signal, slot, or method).

        **See also** **access** ().
        """
        ...

    def access(self) -> "QMetaMethod.Access":
        """
        https://doc.qt.io/qt-6/qmetamethod.html#access

        **QMetaMethod::Access QMetaMethod::access() const**

        Returns the access specification of this method (private, protected, or
        public).

        **Note:** Signals are always public, but you should regard that as an
        implementation detail. It is almost always a bad idea to emit a signal
        from outside its class.

        **See also** **methodType** ().
        """
        ...

    def tag(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#tag

        **const char *QMetaMethod::tag() const**

        Returns the tag associated with this method.

        Tags are special macros recognized by `moc` that make it possible to add
        extra information about a method.

        Tag information can be added in the following way in the function
        declaration:

        // In the class MainWindow declaration
                #ifndef Q_MOC_RUN
        // define the tag text as empty, so the compiler doesn't see it
        #  define MY_CUSTOM_TAG
                #endif
                ...
                private
        slots:
                    MY_CUSTOM_TAG void testFunc();

        and the information can be accessed by using:

        MainWindow win;
                win.show();

                int functionIndex =
        win.metaObject()->indexOfSlot("testFunc()");
                QMetaMethod mm =
        win.metaObject()->method(functionIndex);
                **qDebug** () <<
        mm.tag(); // prints MY_CUSTOM_TAG

        For the moment, `moc` will extract and record all tags, but it will not
        handle any of them specially. You can use the tags to annotate your
        methods differently, and treat them according to the specific needs of
        your application.

        **Note:** Since Qt 5.0, `moc` expands preprocessor macros, so it is
        necessary to surround the definition with `#ifndef` `Q_MOC_RUN`, as
        shown in the example above. This was not required in Qt 4. The code as
        shown above works with Qt 4 too.
        """
        ...

    def parameterNames(self) -> typing.List[QByteArray]:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#parameterNames

        **QList<QByteArray> QMetaMethod::parameterNames() const**

        Returns a list of parameter names.

        **See also** **parameterTypes** () and **methodSignature** ().
        """
        ...

    def parameterTypes(self) -> typing.List[QByteArray]:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#parameterTypes

        **QList<QByteArray> QMetaMethod::parameterTypes() const**

        Returns a list of parameter types.

        **See also** **parameterNames** () and **methodSignature** ().
        """
        ...

    def typeName(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetamethod.html#typeName

        **const char *QMetaMethod::typeName() const**

        Returns the return type name of this method.

        **See also** **returnType** () and **QMetaType::type** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomEntity(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomentity.html

    **Detailed Description**

    This class represents an entity in an XML document, either parsed or
    unparsed. Note that this models the entity itself not the entity
    declaration.

    DOM does not support editing entity nodes; if a user wants to make changes
    to the contents of an entity, every related **QDomEntityReference**  node
    must be replaced in the DOM tree by a clone of the entity's contents, and
    then the desired changes must be made to each of the clones instead. All the
    descendants of an entity node are read-only.

    An entity node does not have any parent.

    You can access the entity's **publicId** (), **systemId** () and
    **notationName** () when available.

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomentity.html#QDomEntity

        **QDomEntity::QDomEntity()**

        Constructs an empty entity.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomEntity") -> None:
        """
        https://doc.qt.io/qt-6/qdomentity.html#QDomEntity-1

        **QDomEntity::QDomEntity(const QDomEntity & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomentity.html#nodeType

        **QDomNode::NodeType QDomEntity::nodeType() const**

        Returns `EntityNode`.
        """
        ...

    def notationName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomentity.html#notationName

        **QString QDomEntity::notationName() const**

        For unparsed entities this function returns the name of the notation for
        the entity. For parsed entities this function returns an empty string.
        """
        ...

    def systemId(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomentity.html#systemId

        **QString QDomEntity::systemId() const**

        Returns the system identifier associated with this entity. If the system
        identifier was not specified an empty string is returned.
        """
        ...

    def publicId(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomentity.html#publicId

        **QString QDomEntity::publicId() const**

        Returns the public identifier associated with this entity. If the public
        identifier was not specified an empty string is returned.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore

PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]
PYQT_OPENGL_ARRAY = typing.Union[
    typing.Sequence[int], typing.Sequence[float], PyQt6.sip.Buffer, None
]
PYQT_OPENGL_BOUND_ARRAY = typing.Union[
    typing.Sequence[int], typing.Sequence[float], PyQt6.sip.Buffer, int, None
]
PYQT_SHADER_ATTRIBUTE_ARRAY = typing.Union[
    typing.Sequence[QtGui.QVector2D],
    typing.Sequence[QtGui.QVector3D],
    typing.Sequence[QtGui.QVector4D],
    typing.Sequence[typing.Sequence[float]],
]
PYQT_SHADER_UNIFORM_VALUE_ARRAY = typing.Union[
    typing.Sequence[QtGui.QVector2D],
    typing.Sequence[QtGui.QVector3D],
    typing.Sequence[QtGui.QVector4D],
    typing.Sequence[QtGui.QMatrix2x2],
    typing.Sequence[QtGui.QMatrix2x3],
    typing.Sequence[QtGui.QMatrix2x4],
    typing.Sequence[QtGui.QMatrix3x2],
    typing.Sequence[QtGui.QMatrix3x3],
    typing.Sequence[QtGui.QMatrix3x4],
    typing.Sequence[QtGui.QMatrix4x2],
    typing.Sequence[QtGui.QMatrix4x3],
    typing.Sequence[QtGui.QMatrix4x4],
    typing.Sequence[typing.Sequence[float]],
]



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QPersistentModelIndex(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpersistentmodelindex.html

    **Detailed Description**

    A QPersistentModelIndex is a model index that can be stored by an
    application, and later used to access information in a model. Unlike the
    **QModelIndex**  class, it is safe to store a QPersistentModelIndex since
    the model will ensure that references to items will continue to be valid as
    long as they can be accessed by the model.

    It is good practice to check that persistent model indexes are valid before
    using them.

    **Note:** You cannot store a **QStandardItemModel** 's QPersistentModelIndex
    in one of the model's items.

    **See also** **Model/View Programming** , **QModelIndex** , and
    **QAbstractItemModel** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#QPersistentModelIndex-
        1

        **QPersistentModelIndex::QPersistentModelIndex(const QModelIndex & index
        )**

        Creates a new QPersistentModelIndex that is a copy of the model
        **index**.
        """
        ...

    @typing.overload
    def __init__(self, index: QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#QPersistentModelIndex-
        2

        **QPersistentModelIndex::QPersistentModelIndex(const
        QPersistentModelIndex & other )**

        Creates a new QPersistentModelIndex that is a copy of the **other**
        persistent model index.
        """
        ...

    @typing.overload
    def __init__(self, other: "QPersistentModelIndex") -> None:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#QPersistentModelIndex-
        3

        **[since 5.2]
        QPersistentModelIndex::QPersistentModelIndex(QPersistentModelIndex &&
        other )**

        Move-constructs a QPersistentModelIndex instance, making it point at the
        same object that **other** was pointing to.

        This function was introduced in Qt 5.2.
        """
        ...

    def __hash__(self) -> int:
        ...

    def swap(self, other: "QPersistentModelIndex") -> None:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#swap

        **[since 5.0] void QPersistentModelIndex::swap(QPersistentModelIndex &
        other )**

        Swaps this persistent modelindex with **other**. This function is very
        fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#isValid

        **bool QPersistentModelIndex::isValid() const**

        Returns `true` if this persistent model index is valid; otherwise
        returns `false`.

        A valid index belongs to a model, and has non-negative row and column
        numbers.

        **See also** **model** (), **row** (), and **column** ().
        """
        ...

    def model(self) -> "QAbstractItemModel":
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#model

        **const QAbstractItemModel *QPersistentModelIndex::model() const**

        Returns the model that the index belongs to.
        """
        ...

    def sibling(self, row: int, column: int) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#sibling

        **QModelIndex QPersistentModelIndex::sibling(int row , int column )
        const**

        Returns the sibling at **row** and **column** or an invalid
        **QModelIndex**  if there is no sibling at this position.

        **See also** **parent** ().
        """
        ...

    def parent(self) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#parent

        **QModelIndex QPersistentModelIndex::parent() const**

        Returns the parent **QModelIndex**  for this persistent index, or an
        invalid **QModelIndex**  if it has no parent.

        **See also** **sibling** () and **model** ().
        """
        ...

    def flags(self) -> Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#flags

        **Qt::ItemFlags QPersistentModelIndex::flags() const**

        Returns the flags for the item referred to by the index.
        """
        ...

    def data(self, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#data

        **QVariant QPersistentModelIndex::data(int role = Qt::DisplayRole)
        const**

        Returns the data for the given **role** for the item referred to by the
        index.

        **See also** **Qt::ItemDataRole**  and **QAbstractItemModel::setData**
        ().
        """
        ...

    def column(self) -> int:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#column

        **int QPersistentModelIndex::column() const**

        Returns the column this persistent model index refers to.
        """
        ...

    def row(self) -> int:
        """
        https://doc.qt.io/qt-6/qpersistentmodelindex.html#row

        **int QPersistentModelIndex::row() const**

        Returns the row this persistent model index refers to.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QWidgetAction(QtGui.QAction):
    """
    https://doc.qt.io/qt-6/qwidgetaction.html

    **Detailed Description**

    Most actions in an application are represented as items in menus or buttons
    in toolbars. However sometimes more complex widgets are necessary. For
    example a zoom action in a word processor may be realized using a
    **QComboBox**  in a **QToolBar** , presenting a range of different zoom
    levels. **QToolBar**  provides **QToolBar::insertWidget** () as convenience
    function for inserting a single widget. However if you want to implement an
    action that uses custom widgets for visualization in multiple containers
    then you have to subclass QWidgetAction.

    If a QWidgetAction is added for example to a **QToolBar**  then
    **QWidgetAction::createWidget** () is called. Reimplementations of that
    function should create a new custom widget with the specified parent.

    If the action is removed from a container widget then
    **QWidgetAction::deleteWidget** () is called with the previously created
    custom widget as argument. The default implementation hides the widget and
    deletes it using **QObject::deleteLater** ().

    If you have only one single custom widget then you can set it as default
    widget using **setDefaultWidget** (). That widget will then be used if the
    action is added to a **QToolBar** , or in general to an action container
    that supports QWidgetAction. If a QWidgetAction with only a default widget
    is added to two toolbars at the same time then the default widget is shown
    only in the first toolbar the action was added to. QWidgetAction takes over
    ownership of the default widget.

    Note that it is up to the widget to activate the action, for example by
    reimplementing mouse event handlers and calling **QAction::trigger** ().

    **macOS** : If you add a widget to a menu in the application's menu bar on
    macOS, the widget will be added and it will function but with some
    limitations:

    1. The widget is reparented away from the **QMenu**  to the native menu
    view. If you show the menu in some other place (e.g. as a popup menu), the
    widget will not be there.
      2. Focus/Keyboard handling of the widget is not
    possible.
      3. Due to Apple's design, mouse tracking on the widget currently
    does not work.
      4. Connecting the **triggered** () signal to a slot that
    opens a modal dialog will cause a crash in macOS 10.4 (known bug
    acknowledged by Apple), a workaround is to use a QueuedConnection instead of
    a DirectConnection.

    **See also** **QAction** , **QActionGroup** , and **QWidget** .
    """

    def __init__(self, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#QWidgetAction

        **QWidgetAction::QWidgetAction(QObject * parent )**

        Constructs an action with **parent**.
        """
        ...

    def createdWidgets(self) -> typing.List[QWidget]:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#createdWidgets

        **[protected] QList<QWidget *> QWidgetAction::createdWidgets() const**

        Returns the list of widgets that have been using **createWidget** () and
        are currently in use by widgets the action has been added to.
        """
        ...

    def deleteWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#deleteWidget

        **[virtual protected] void QWidgetAction::deleteWidget(QWidget * widget
        )**

        This function is called whenever the action is removed from a container
        widget that displays the action using a custom **widget** previously
        created using **createWidget** (). The default implementation hides the
        **widget** and schedules it for deletion using **QObject::deleteLater**
        ().

        **See also** **createWidget** ().
        """
        ...

    def createWidget(self, parent: QWidget) -> QWidget:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#createWidget

        **[virtual protected] QWidget *QWidgetAction::createWidget(QWidget *
        parent )**

        This function is called whenever the action is added to a container
        widget that supports custom widgets. If you don't want a custom widget
        to be used as representation of the action in the specified **parent**
        widget then 0 should be returned.

        **See also** **deleteWidget** ().
        """
        ...

    def eventFilter(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#eventFilter

        **[override virtual protected] bool QWidgetAction::eventFilter(QObject *
        obj , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#event

        **[override virtual protected] bool QWidgetAction::event(QEvent * event
        )**

        Reimplements: **QAction::event** (QEvent *e).
        """
        ...

    def releaseWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#releaseWidget

        **void QWidgetAction::releaseWidget(QWidget * widget )**

        Releases the specified **widget**.

        Container widgets that support actions call this function when a widget
        action is removed.

        **See also** **requestWidget** (), **deleteWidget** (), and
        **defaultWidget** ().
        """
        ...

    def requestWidget(self, parent: QWidget) -> QWidget:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#requestWidget

        **QWidget *QWidgetAction::requestWidget(QWidget * parent )**

        Returns a widget that represents the action, with the given **parent**.

        Container widgets that support actions can call this function to request
        a widget as visual representation of the action.

        **See also** **releaseWidget** (), **createWidget** (), and
        **defaultWidget** ().
        """
        ...

    def defaultWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#defaultWidget

        **QWidget *QWidgetAction::defaultWidget() const**

        Returns the default widget.

        **See also** **setDefaultWidget** ().
        """
        ...

    def setDefaultWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qwidgetaction.html#setDefaultWidget

        **void QWidgetAction::setDefaultWidget(QWidget * widget )**

        Sets **widget** to be the default widget. The ownership is transferred
        to **QWidgetAction** . Unless **createWidget** () is reimplemented by a
        subclass to return a new widget the default widget is used when a
        container widget requests a widget through **requestWidget** ().

        **See also** **defaultWidget** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTransform(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtransform.html

    **Detailed Description**

    A transformation specifies how to translate, scale, shear, rotate or project
    the coordinate system, and is typically used when rendering graphics.

    A QTransform object can be built using the **setMatrix** (), **scale** (),
    **rotate** (), **translate** () and **shear** () functions. Alternatively,
    it can be built by applying **basic matrix operations** . The matrix can
    also be defined when constructed, and it can be reset to the identity matrix
    (the default) using the **reset** () function.

    The QTransform class supports mapping of graphic primitives: A given point,
    line, polygon, region, or painter path can be mapped to the coordinate
    system defined by **this** matrix using the **map** () function. In case of
    a rectangle, its coordinates can be transformed using the **mapRect** ()
    function. A rectangle can also be transformed into a **polygon** (mapped to
    the coordinate system defined by **this** matrix), using the
    **mapToPolygon** () function.

    QTransform provides the **isIdentity** () function which returns `true` if
    the matrix is the identity matrix, and the **isInvertible** () function
    which returns `true` if the matrix is non-singular (i.e. AB = BA = I). The
    **inverted** () function returns an inverted copy of **this** matrix if it
    is invertible (otherwise it returns the identity matrix), and **adjoint** ()
    returns the matrix's classical adjoint. In addition, QTransform provides the
    **determinant** () function which returns the matrix's determinant.

    Finally, the QTransform class supports matrix multiplication, addition and
    subtraction, and objects of the class can be streamed as well as compared.

    **Rendering Graphics**

    When rendering graphics, the matrix defines the transformations but the
    actual transformation is performed by the drawing routines in **QPainter** .

    By default, **QPainter**  operates on the associated device's own coordinate
    system. The standard coordinate system of a **QPaintDevice**  has its origin
    located at the top-left position. The **x** values increase to the right;
    **y** values increase downward. For a complete description, see the
    **coordinate system**  documentation.

    **QPainter**  has functions to translate, scale, shear and rotate the
    coordinate system without using a QTransform. For example:

    ![](images/qtransform-simpletransformation.png)



        void
    SimpleTransformation::paintEvent(**QPaintEvent**  *)
        {
    **QPainter**  painter(this);
            painter.setPen(**QPen** (Qt::blue, 1,
    Qt::DashLine));
            painter.drawRect(0, 0, 100, 100);
    painter.rotate(45);

            painter.setFont(**QFont** ("Helvetica",
    24));
            painter.setPen(**QPen** (Qt::black, 1));
    painter.drawText(20, 10, "QTransform");
        }

    Although these functions are very convenient, it can be more efficient to
    build a QTransform and call **QPainter::setTransform** () if you want to
    perform more than a single transform operation. For example:

    ![](images/qtransform-combinedtransformation.png)



        void
    CombinedTransformation::paintEvent(**QPaintEvent**  *)
        {
    **QPainter**  painter(this);
            painter.setPen(**QPen** (Qt::blue, 1,
    Qt::DashLine));
            painter.drawRect(0, 0, 100, 100);
    QTransform transform;
            transform.translate(50, 50);
    transform.rotate(45);
            transform.scale(0.5, 1.0);
    painter.setTransform(transform);

            painter.setFont(**QFont**
    ("Helvetica", 24));
            painter.setPen(**QPen** (Qt::black, 1));
    painter.drawText(20, 10, "QTransform");
        }

    **Basic Matrix Operations**

    ![](images/qtransform-representation.png)

    A QTransform object contains a 3 x 3 matrix. The `m31` (`dx`) and `m32`
    (`dy`) elements specify horizontal and vertical translation. The `m11` and
    `m22` elements specify horizontal and vertical scaling. The `m21` and `m12`
    elements specify horizontal and vertical **shearing**. And finally, the
    `m13` and `m23` elements specify horizontal and vertical projection, with
    `m33` as an additional projection factor.

    QTransform transforms a point in the plane to another point using the
    following formulas:

    x' = m11*x + m21*y + dx
        y' = m22*y + m12*x + dy
        if (!isAffine()) {
    w' = m13*x + m23*y + m33
            x' /= w'
            y' /= w'
        }

    The point **(x, y)** is the original point, and **(x', y')** is the
    transformed point. **(x', y')** can be transformed back to **(x, y)** by
    performing the same operation on the **inverted** () matrix.

    The various matrix elements can be set when constructing the matrix, or by
    using the **setMatrix** () function later on. They can also be manipulated
    using the **translate** (), **rotate** (), **scale** () and **shear** ()
    convenience functions. The currently set values can be retrieved using the
    **m11** (), **m12** (), **m13** (), **m21** (), **m22** (), **m23** (),
    **m31** (), **m32** (), **m33** (), **dx** () and **dy** () functions.

    Translation is the simplest transformation. Setting `dx` and `dy` will move
    the coordinate system `dx` units along the X axis and `dy` units along the Y
    axis. Scaling can be done by setting `m11` and `m22`. For example, setting
    `m11` to 2 and `m22` to 1.5 will double the height and increase the width by
    50%. The identity matrix has `m11`, `m22`, and `m33` set to 1 (all others
    are set to 0) mapping a point to itself. Shearing is controlled by `m12` and
    `m21`. Setting these elements to values different from zero will twist the
    coordinate system. Rotation is achieved by setting both the shearing factors
    and the scaling factors. Perspective transformation is achieved by setting
    both the projection factors and the scaling factors.

    **Combining Transforms**

    Here's the combined transformations example using basic matrix operations:

    ![](images/qtransform-combinedtransformation2.png)



        void
    BasicOperations::paintEvent(**QPaintEvent**  *)
        {
            const double a
    = qDegreesToRadians(45.0);
            double sina = sin(a);
            double cosa
    = cos(a);

            QTransform scale(0.5, 0, 0, 1.0, 0, 0);
    QTransform rotate(cosa, sina, -sina, cosa, 0, 0);
            QTransform
    translate(1, 0, 0, 1, 50.0, 50.0);

            QTransform transform = scale
    * rotate * translate;

            **QPainter**  painter(this);
    painter.setPen(**QPen** (Qt::blue, 1, Qt::DashLine));
    painter.drawRect(0, 0, 100, 100);
    painter.setTransform(transform);

            painter.setFont(**QFont**
    ("Helvetica", 24));
            painter.setPen(**QPen** (Qt::black, 1));
    painter.drawText(20, 10, "QTransform");
        }

    The combined transform first scales each operand, then rotates it, and
    finally translates it, just as in the order in which the product of its
    factors is written. This means the point to which the transforms are applied
    is implicitly multiplied on the left with the transform to its right.

    **Relation to Matrix Notation**

    The matrix notation in QTransform is the transpose of a commonly-taught
    convention which represents transforms and points as matrices and vectors.
    That convention multiplies its matrix on the left and column vector to the
    right. In other words, when several transforms are applied to a point, the
    right-most matrix acts directly on the vector first. Then the next matrix to
    the left acts on the result of the first operation - and so on. As a result,
    that convention multiplies the matrices that make up a composite transform
    in the reverse of the order in QTransform, as you can see in **Combining
    Transforms** . Transposing the matrices, and combining them to the right of
    a row vector that represents the point, lets the matrices of transforms
    appear, in their product, in the order in which we think of the transforms
    being applied to the point.

    **See also** **QPainter** , **Coordinate System** , **Affine Transformations
    Example** , and **Transformations Example** .
    """

    class TransformationType(enum.Enum):
        TxNone: QTransform = ...
        TxTranslate: QTransform = ...
        TxScale: QTransform = ...
        TxRotate: QTransform = ...
        TxShear: QTransform = ...
        TxProject: QTransform = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtransform.html#QTransform-1

        **QTransform::QTransform()**

        Constructs an identity matrix.

        All elements are set to zero except `m11` and `m22` (specifying the
        scale) and `m33` which are set to 1.

        **See also** **reset** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        h11: float,
        h12: float,
        h13: float,
        h21: float,
        h22: float,
        h23: float,
        h31: float,
        h32: float,
        h33: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtransform.html#QTransform-2

        **QTransform::QTransform(qreal m11 , qreal m12 , qreal m13 , qreal m21 ,
        qreal m22 , qreal m23 , qreal m31 , qreal m32 , qreal m33 )**

        Constructs a matrix with the elements, **m11** , **m12** , **m13** ,
        **m21** , **m22** , **m23** , **m31** , **m32** , **m33**.

        **See also** **setMatrix** ().
        """
        ...

    @typing.overload
    def __init__(
        self, h11: float, h12: float, h13: float, h21: float, h22: float, h23: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtransform.html#QTransform-3

        **QTransform::QTransform(qreal m11 , qreal m12 , qreal m21 , qreal m22 ,
        qreal dx , qreal dy )**

        Constructs a matrix with the elements, **m11** , **m12** , **m21** ,
        **m22** , **dx** and **dy**.

        **See also** **setMatrix** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QTransform") -> None:
        """
        https://doc.qt.io/qt-6/qtransform.html#QTransform-1

        **QTransform::QTransform()**

        Constructs an identity matrix.

        All elements are set to zero except `m11` and `m22` (specifying the
        scale) and `m33` which are set to 1.

        **See also** **reset** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    @staticmethod
    def fromScale(dx: float, dy: float) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#fromScale

        **[static] QTransform QTransform::fromScale(qreal sx , qreal sy )**

        Creates a matrix which corresponds to a scaling of **sx** horizontally
        and **sy** vertically. This is the same as **QTransform** ().scale(sx,
        sy) but slightly faster.
        """
        ...

    @staticmethod
    def fromTranslate(dx: float, dy: float) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#fromTranslate

        **[static] QTransform QTransform::fromTranslate(qreal dx , qreal dy )**

        Creates a matrix which corresponds to a translation of **dx** along the
        x axis and **dy** along the y axis. This is the same as **QTransform**
        ().translate(dx, dy) but slightly faster.
        """
        ...

    def dy(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#dy

        **qreal QTransform::dy() const**

        Returns the vertical translation factor.

        **See also** **translate** () and **Basic Matrix Operations** .
        """
        ...

    def dx(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#dx

        **qreal QTransform::dx() const**

        Returns the horizontal translation factor.

        **See also** **m31** (), **translate** (), and **Basic Matrix
        Operations** .
        """
        ...

    def m33(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m33

        **qreal QTransform::m33() const**

        Returns the division factor.

        **See also** **translate** () and **Basic Matrix Operations** .
        """
        ...

    def m32(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m32

        **qreal QTransform::m32() const**

        Returns the vertical translation factor.

        **See also** **dy** (), **translate** (), and **Basic Matrix
        Operations** .
        """
        ...

    def m31(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m31

        **qreal QTransform::m31() const**

        Returns the horizontal translation factor.

        **See also** **dx** (), **translate** (), and **Basic Matrix
        Operations** .
        """
        ...

    def m23(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m23

        **qreal QTransform::m23() const**

        Returns the vertical projection factor.

        **See also** **translate** () and **Basic Matrix Operations** .
        """
        ...

    def m22(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m22

        **qreal QTransform::m22() const**

        Returns the vertical scaling factor.

        **See also** **scale** () and **Basic Matrix Operations** .
        """
        ...

    def m21(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m21

        **qreal QTransform::m21() const**

        Returns the horizontal shearing factor.

        **See also** **shear** () and **Basic Matrix Operations** .
        """
        ...

    def m13(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m13

        **qreal QTransform::m13() const**

        Returns the horizontal projection factor.

        **See also** **translate** () and **Basic Matrix Operations** .
        """
        ...

    def m12(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m12

        **qreal QTransform::m12() const**

        Returns the vertical shearing factor.

        **See also** **shear** () and **Basic Matrix Operations** .
        """
        ...

    def m11(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#m11

        **qreal QTransform::m11() const**

        Returns the horizontal scaling factor.

        **See also** **scale** () and **Basic Matrix Operations** .
        """
        ...

    def determinant(self) -> float:
        """
        https://doc.qt.io/qt-6/qtransform.html#determinant

        **qreal QTransform::determinant() const**

        Returns the matrix's determinant.
        """
        ...

    def isTranslating(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#isTranslating

        **bool QTransform::isTranslating() const**

        Returns `true` if the matrix represents a translating transformation,
        otherwise returns `false`.

        **See also** **reset** ().
        """
        ...

    def isRotating(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#isRotating

        **bool QTransform::isRotating() const**

        Returns `true` if the matrix represents some kind of a rotating
        transformation, otherwise returns `false`.

        **Note:** A rotation transformation of 180 degrees and/or 360 degrees is
        treated as a scaling transformation.

        **See also** **reset** ().
        """
        ...

    def isScaling(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#isScaling

        **bool QTransform::isScaling() const**

        Returns `true` if the matrix represents a scaling transformation,
        otherwise returns `false`.

        **See also** **reset** ().
        """
        ...

    def isInvertible(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#isInvertible

        **bool QTransform::isInvertible() const**

        Returns `true` if the matrix is invertible, otherwise returns `false`.

        **See also** **inverted** ().
        """
        ...

    def isIdentity(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#isIdentity

        **bool QTransform::isIdentity() const**

        Returns `true` if the matrix is the identity matrix, otherwise returns
        `false`.

        **See also** **reset** ().
        """
        ...

    def isAffine(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#isAffine

        **bool QTransform::isAffine() const**

        Returns `true` if the matrix represent an affine transformation,
        otherwise returns `false`.
        """
        ...

    @typing.overload
    def mapRect(self, a0: QtCore.QRect) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qtransform.html#mapRect

        **QRectF QTransform::mapRect(const QRectF & rectangle ) const**

        Creates and returns a **QRectF**  object that is a copy of the given
        **rectangle** , mapped into the coordinate system defined by this
        matrix.

        The rectangle's coordinates are transformed using the following
        formulas:

        x' = m11*x + m21*y + dx
            y' = m22*y + m12*x + dy
            if (!isAffine())
        {
                w' = m13*x + m23*y + m33
                x' /= w'
                y' /= w'
        }

        If rotation or shearing has been specified, this function returns the
        **bounding** rectangle. To retrieve the exact region the given
        **rectangle** maps to, use the **mapToPolygon** () function instead.

        **See also** **mapToPolygon** () and **Basic Matrix Operations** .
        """
        ...

    @typing.overload
    def mapRect(self, a0: QtCore.QRectF) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qtransform.html#mapRect-1

        **QRect QTransform::mapRect(const QRect & rectangle ) const**

        This is an overloaded function.

        Creates and returns a **QRect**  object that is a copy of the given
        **rectangle** , mapped into the coordinate system defined by this
        matrix. Note that the transformed coordinates are rounded to the nearest
        integer.
        """
        ...

    def mapToPolygon(self, r: QtCore.QRect) -> QPolygon:
        """
        https://doc.qt.io/qt-6/qtransform.html#mapToPolygon

        **QPolygon QTransform::mapToPolygon(const QRect & rectangle ) const**

        Creates and returns a **QPolygon**  representation of the given
        **rectangle** , mapped into the coordinate system defined by this
        matrix.

        The rectangle's coordinates are transformed using the following
        formulas:

        x' = m11*x + m21*y + dx
            y' = m22*y + m12*x + dy
            if (!isAffine())
        {
                w' = m13*x + m23*y + m33
                x' /= w'
                y' /= w'
        }

        Polygons and rectangles behave slightly differently when transformed
        (due to integer rounding), so `matrix.map(QPolygon(rectangle))` is not
        always the same as `matrix.mapToPolygon(rectangle)`.

        **See also** **mapRect** () and **Basic Matrix Operations** .
        """
        ...

    @typing.overload
    def map(self, x: int, y: int) -> typing.Tuple[int, int]:
        """
        https://doc.qt.io/qt-6/qtransform.html#map

        **void QTransform::map(qreal x , qreal y , qreal * tx , qreal * ty )
        const**

        Maps the given coordinates **x** and **y** into the coordinate system
        defined by this matrix. The resulting values are put in * **tx** and *
        **ty** , respectively.

        The coordinates are transformed using the following formulas:

        x' = m11*x + m21*y + dx
            y' = m22*y + m12*x + dy
            if (!isAffine())
        {
                w' = m13*x + m23*y + m33
                x' /= w'
                y' /= w'
        }

        The point (x, y) is the original point, and (x', y') is the transformed
        point.

        **See also** **Basic Matrix Operations** .
        """
        ...

    @typing.overload
    def map(self, x: float, y: float) -> typing.Tuple[float, float]:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-1

        **QPoint QTransform::map(const QPoint & point ) const**

        This is an overloaded function.

        Creates and returns a **QPoint**  object that is a copy of the given
        **point** , mapped into the coordinate system defined by this matrix.
        Note that the transformed coordinates are rounded to the nearest
        integer.
        """
        ...

    @typing.overload
    def map(self, p: QtCore.QPoint) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-2

        **QPointF QTransform::map(const QPointF & p ) const**

        This is an overloaded function.

        Creates and returns a **QPointF**  object that is a copy of the given
        point, **p** , mapped into the coordinate system defined by this matrix.
        """
        ...

    @typing.overload
    def map(self, p: QtCore.QPointF) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-3

        **QLine QTransform::map(const QLine & l ) const**

        This is an overloaded function.

        Creates and returns a **QLineF**  object that is a copy of the given
        line, **l** , mapped into the coordinate system defined by this matrix.
        """
        ...

    @typing.overload
    def map(self, l: QtCore.QLine) -> QtCore.QLine:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-4

        **QLineF QTransform::map(const QLineF & line ) const**

        This is an overloaded function.

        Creates and returns a **QLine**  object that is a copy of the given
        **line** , mapped into the coordinate system defined by this matrix.
        Note that the transformed coordinates are rounded to the nearest
        integer.
        """
        ...

    @typing.overload
    def map(self, l: QtCore.QLineF) -> QtCore.QLineF:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-5

        **QPolygonF QTransform::map(const QPolygonF & polygon ) const**

        This is an overloaded function.

        Creates and returns a **QPolygonF**  object that is a copy of the given
        **polygon** , mapped into the coordinate system defined by this matrix.
        """
        ...

    @typing.overload
    def map(self, a: QPolygonF) -> QPolygonF:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-6

        **QPolygon QTransform::map(const QPolygon & polygon ) const**

        This is an overloaded function.

        Creates and returns a **QPolygon**  object that is a copy of the given
        **polygon** , mapped into the coordinate system defined by this matrix.
        Note that the transformed coordinates are rounded to the nearest
        integer.
        """
        ...

    @typing.overload
    def map(self, a: QPolygon) -> QPolygon:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-7

        **QRegion QTransform::map(const QRegion & region ) const**

        This is an overloaded function.

        Creates and returns a **QRegion**  object that is a copy of the given
        **region** , mapped into the coordinate system defined by this matrix.

        Calling this method can be rather expensive if rotations or shearing are
        used.
        """
        ...

    @typing.overload
    def map(self, r: QRegion) -> QRegion:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-8

        **QPainterPath QTransform::map(const QPainterPath & path ) const**

        This is an overloaded function.

        Creates and returns a **QPainterPath**  object that is a copy of the
        given **path** , mapped into the coordinate system defined by this
        matrix.
        """
        ...

    @typing.overload
    def map(self, p: QPainterPath) -> QPainterPath:
        """
        https://doc.qt.io/qt-6/qtransform.html#map-9

        **void QTransform::map(int x , int y , int * tx , int * ty ) const**

        This is an overloaded function.

        Maps the given coordinates **x** and **y** into the coordinate system
        defined by this matrix. The resulting values are put in * **tx** and *
        **ty** , respectively. Note that the transformed coordinates are rounded
        to the nearest integer.
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qtransform.html#reset

        **void QTransform::reset()**

        Resets the matrix to an identity matrix, i.e. all elements are set to
        zero, except `m11` and `m22` (specifying the scale) and `m33` which are
        set to 1.

        **See also** **QTransform** (), **isIdentity** (), and **Basic Matrix
        Operations** .
        """
        ...

    @staticmethod
    def quadToQuad(one: QPolygonF, two: QPolygonF, result: "QTransform") -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#quadToQuad

        **[static] bool QTransform::quadToQuad(const QPolygonF & one , const
        QPolygonF & two , QTransform & trans )**

        Creates a transformation matrix, **trans** , that maps a four-sided
        polygon, **one** , to another four-sided polygon, **two**. Returns
        `true` if the transformation is possible; otherwise returns false.

        This is a convenience method combining **quadToSquare** () and
        **squareToQuad** () methods. It allows the input quad to be transformed
        into any other quad.

        **See also** **squareToQuad** () and **quadToSquare** ().
        """
        ...

    @staticmethod
    def quadToSquare(quad: QPolygonF, result: "QTransform") -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#quadToSquare

        **[static] bool QTransform::quadToSquare(const QPolygonF & quad ,
        QTransform & trans )**

        Creates a transformation matrix, **trans** , that maps a four-sided
        polygon, **quad** , to a unit square. Returns `true` if the
        transformation is constructed or false if such a transformation does not
        exist.

        **See also** **squareToQuad** () and **quadToQuad** ().
        """
        ...

    @staticmethod
    def squareToQuad(square: QPolygonF, result: "QTransform") -> bool:
        """
        https://doc.qt.io/qt-6/qtransform.html#squareToQuad

        **[static] bool QTransform::squareToQuad(const QPolygonF & quad ,
        QTransform & trans )**

        Creates a transformation matrix, **trans** , that maps a unit square to
        a four-sided polygon, **quad**. Returns `true` if the transformation is
        constructed or false if such a transformation does not exist.

        **See also** **quadToSquare** () and **quadToQuad** ().
        """
        ...

    def rotateRadians(self, angle: float, axis: QtCore.Qt.Axis = ...) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#rotateRadians

        **QTransform &QTransform::rotateRadians(qreal angle , Qt::Axis axis =
        Qt::ZAxis)**

        Rotates the coordinate system counterclockwise by the given **angle**
        about the specified **axis** and returns a reference to the matrix.

        Note that if you apply a **QTransform**  to a point defined in widget
        coordinates, the direction of the rotation will be clockwise because the
        y-axis points downwards.

        The angle is specified in radians.

        **See also** **setMatrix** ().
        """
        ...

    def rotate(self, angle: float, axis: QtCore.Qt.Axis = ...) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#rotate

        **QTransform &QTransform::rotate(qreal angle , Qt::Axis axis =
        Qt::ZAxis)**

        Rotates the coordinate system counterclockwise by the given **angle**
        about the specified **axis** and returns a reference to the matrix.

        Note that if you apply a **QTransform**  to a point defined in widget
        coordinates, the direction of the rotation will be clockwise because the
        y-axis points downwards.

        The angle is specified in degrees.

        **See also** **setMatrix** ().
        """
        ...

    def shear(self, sh: float, sv: float) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#shear

        **QTransform &QTransform::shear(qreal sh , qreal sv )**

        Shears the coordinate system by **sh** horizontally and **sv**
        vertically, and returns a reference to the matrix.

        **See also** **setMatrix** ().
        """
        ...

    def scale(self, sx: float, sy: float) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#scale

        **QTransform &QTransform::scale(qreal sx , qreal sy )**

        Scales the coordinate system by **sx** horizontally and **sy**
        vertically, and returns a reference to the matrix.

        **See also** **setMatrix** ().
        """
        ...

    def translate(self, dx: float, dy: float) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#translate

        **QTransform &QTransform::translate(qreal dx , qreal dy )**

        Moves the coordinate system **dx** along the x axis and **dy** along the
        y axis, and returns a reference to the matrix.

        **See also** **setMatrix** ().
        """
        ...

    def transposed(self) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#transposed

        **QTransform QTransform::transposed() const**

        Returns the transpose of this matrix.
        """
        ...

    def adjoint(self) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qtransform.html#adjoint

        **QTransform QTransform::adjoint() const**

        Returns the adjoint of this matrix.
        """
        ...

    def inverted(self) -> typing.Tuple["QTransform", bool]:
        """
        https://doc.qt.io/qt-6/qtransform.html#inverted

        **QTransform QTransform::inverted(bool * invertible = nullptr) const**

        Returns an inverted copy of this matrix.

        If the matrix is singular (not invertible), the returned matrix is the
        identity matrix. If **invertible** is valid (i.e. not 0), its value is
        set to true if the matrix is invertible, otherwise it is set to false.

        **See also** **isInvertible** ().
        """
        ...

    def setMatrix(
        self,
        m11: float,
        m12: float,
        m13: float,
        m21: float,
        m22: float,
        m23: float,
        m31: float,
        m32: float,
        m33: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtransform.html#setMatrix

        **void QTransform::setMatrix(qreal m11 , qreal m12 , qreal m13 , qreal
        m21 , qreal m22 , qreal m23 , qreal m31 , qreal m32 , qreal m33 )**

        Sets the matrix elements to the specified values, **m11** , **m12** ,
        **m13** **m21** , **m22** , **m23** **m31** , **m32** and **m33**. Note
        that this function replaces the previous values. **QTransform**
        provides the **translate** (), **rotate** (), **scale** () and **shear**
        () convenience functions to manipulate the various matrix elements based
        on the currently defined coordinate system.

        **See also** **QTransform** ().
        """
        ...

    def type(self) -> "QTransform.TransformationType":
        """
        https://doc.qt.io/qt-6/qtransform.html#type

        **QTransform::TransformationType QTransform::type() const**

        Returns the transformation type of this matrix.

        The transformation type is the highest enumeration value capturing all
        of the matrix's transformations. For example, if the matrix both scales
        and shears, the type would be `TxShear`, because `TxShear` has a higher
        enumeration value than `TxScale`.

        Knowing the transformation type of a matrix is useful for optimization:
        you can often handle specific types more optimally than handling the
        generic case.
        """
        ...
